@@ -203,7 +203,7 @@ function connect_pdo($dsn_array) {
 	$password = $dsn_array['password'];
 	$persistent = (bool) $dsn_array['persistent'];
 	$path = $dsn_array['path'];
-	if(substr($path,0,1)!='/') $path = realpath('../'.$path);
+	if(substr($path,0,1)!='/') $path = $this->__page_obj->home_dir.'/'.$path;
 	try {
 		if($system=='pgsql') {
 			if(!$port) $port = '5432';
@@ -338,6 +338,7 @@ function insert_table($data) {
 				//echo "data_type=$data_type<br>";
 				$value = call_user_func(array($this,'save_'.$data_type.'_value'),$column,$data[$column]);
 				$ivalues_array[] = $value;
+				$result[$this->current_table][$column] = $value;
 			}
 		}
 		$icolumns = implode(',', $icoumns_array);
@@ -403,6 +404,7 @@ function update_table($data,$condition) {
 				$value = call_user_func(array($this,'save_'.$data_type.'_value'),$column,$data[$column]);
 				if($data_type=='password' and $value===NULL) continue;
 				$update_set_array[]= $column.'='.$value;
+				$result[$this->current_table][$column] = $value;
 			}
 		}
 		if(count($update_set_array)<1) {
