@@ -29,6 +29,7 @@ class Quicty extends Smarty {
 	protected $dispatch_action;
 	protected $class_name; 
 	protected $module_dir;
+	protected $component_dir;
 	protected $form_result;
 	protected $quicty_plugin_names;
 	protected $pathlist = array(0=>array(name=>'ȥå',url=>'/'));
@@ -64,7 +65,7 @@ class Quicty extends Smarty {
 
 function __construct($home_dir='..',$control='submit') {
 	$this->Smarty();
-	$this->home_dir = $home_dir;
+	$this->home_dir = realpath($home_dir);
 	$this->template_dir = $home_dir.'/view';
 	$this->compile_dir = $home_dir.'/var/compiled_view';
 	$this->plugins_dir[] = $home_dir.'/lib/smarty_plugins';
@@ -73,6 +74,7 @@ function __construct($home_dir='..',$control='submit') {
 	$this->caching = 0; // smarty caching is off
 	$this->config_dir = $home_dir.'/etc';
 	$this->module_dir = $home_dir.'/lib/Pages';
+	$this->component_dir = $home_dir.'/lib/Components';
 	
 	if($_SERVER['DOCUMENT_ROOT']) {
 		$this->root_dir = substr($_SERVER['DOCUMENT_ROOT'],0,strrpos($_SERVER['DOCUMENT_ROOT'],'/'));
@@ -374,6 +376,26 @@ public function set_qs_status($status) {
 	return $this->set_qt_status($status);
 }
 
+/**
+ *	DI Component experimental implementation.
+ *
+ */
+
+/**
+ *	Create new Component instance.
+ *
+ *	@access	public
+ *	@param	string $file_path kind and name of plugin. such as 'sidebar/calendar'.
+ *	@return	object plugin instance object.
+ */
+public function new_component($file_path) {
+	require_once $this->component_dir.'/'.$file_path.$this->regular_class_ext;
+	$file = pathinfo($file_path);
+	$class_name = $file['basename'];
+	$component = new $class_name($this,$params);
+	return $component;
+}
+
 
 /**
  *	Create Quicty::DataView object.
@@ -870,9 +892,10 @@ public function __toString() {
 	return $this->class_name;
 }
 
-public function __autoload($class_name) {
-	require_once $this->module_dir.'/'.$class_name.$this->regular_class_ext;
-}
+
+//public function __autoload($class_name) {
+//	require_once $this->component_dir.'/'.$class_name.$this->regular_class_ext;
+//}
 
 
 
